@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from .classification_dataset import ClassificationDataset
 from .nlp_dataset import NLPDataset
-from .bert_classification_dataset import BertClassificationDataset
+from .bert_dataset import BertClassificationDataset
 
 
 __all__ = [
